const mode = window.acquireVsCodeApi === undefined ? 'debug' : 'release';
console.log('digital-vcd-viewer mode: ' + mode);

let vscode = window.acquireVsCodeApi === undefined ? undefined : acquireVsCodeApi();

import { globalLookup, globalSetting } from '@/hook/global';
import { makeSaveViewPayload } from '@/hook/recover';
import axios from 'axios';

export let saveDelay = 1000;

/**
 * 
 * @param {string} file 
 * @param {any} payload 
 */
export async function saveView(file, payload) {
    if (payload === undefined) {
        return;
    }
    if (mode === 'debug') {
        const res = await axios.post('http://localhost:3000/save-view', { file, payload });
        // const res = await axios.get('http://localhost:3000');
        console.log(res);
    } else {
        vscode.postMessage({
            command: 'save-view',
            data: { file, payload }
        });
    }
}


/**
 * 
 * @param {number} delay 
 * @returns {(config: import('@/hook/recover').SavePayloadConfig) => void}
 */
function debounceSaveView(delay) {
    let timer;
    const configPool = {};
    return function (config) {
        if (!globalSetting.autoSaveView) {
            return;
        }
        // 记录所有的 payload tag
        Object.assign(configPool, config);

        if (timer) {
            clearTimeout(timer);
        }
        timer = setTimeout(() => {
            const payload = makeSaveViewPayload(configPool);            
            const savePath = globalLookup.originVcdViewFile;
            saveView(savePath, payload);
        }, delay);
    }
}

export const saveViewApi = debounceSaveView(saveDelay);